RewardedInterstitialAdPreloader class

Pool-based preloader for RewardedInterstitialAds. Same shape as InterstitialAdPreloader — see its docs for usage.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

count({required String adUnitId}) Future<int>
destroy({required String adUnitId}) Future<bool>
isAvailable({required String adUnitId}) Future<bool>
poll({required String adUnitId}) Future<RewardedInterstitialAd?>
start({required String adUnitId, AdRequest? request, int? bufferSize}) Future<bool>